@@ -1,10 +1,9 @@
-from .download import download
-from .load_info import load_info
 from .filter_required_cell_lines import filter_required_cell_lines
 from .validate_common_parameters import validate_common_parameters
 from .center_window import center_window
 from .normalize_cell_lines import normalize_cell_lines
 from .normalize_bed_file import normalize_bed_file
+from .load_bed import load_bed
 
-__all__ = ["download", "load_info", "filter_required_cell_lines",
+__all__ = ["filter_required_cell_lines", "load_bed",
            "validate_common_parameters", "center_window", "normalize_cell_lines", "normalize_bed_file"]
