@@ -18,10 +18,16 @@ def normalize_bed_file(cell_lines: List[str], bed_file: pd.DataFrame) -> pd.Data
     """
     if "strand" not in bed_file:
         bed_file["strand"] = "."
-    df = bed_file[["chromosome", "start",
+    cell_lines = [
+        cell_line
+        for cell_line in cell_lines
+        if cell_line in bed_file.columns
+    ]
+    df = bed_file[["chrom", "start",
                    "end", "strand", *sorted(cell_lines)]]
-    return df.rename(columns={
-        "chromosome": "chrom",
-        "start": "chromStart",
-        "end": "chromEnd"
-    })
+    return df.rename(
+        columns={
+            "start": "chromStart",
+            "end": "chromEnd"
+        }
+    )
\ No newline at end of file
